aboutsummaryrefslogtreecommitdiffstats
path: root/contrib/libucl/ucl.h
diff options
context:
space:
mode:
authorAlexander Moisseev <moiseev@mezonplus.ru>2017-06-27 10:44:19 +0300
committerAlexander Moisseev <moiseev@mezonplus.ru>2017-06-27 10:44:19 +0300
commitbb5a9f8e451bc206e78c9d4d03eb4cbdbef260b3 (patch)
treeec38b50c99765caed67aaf23db308b17cc407d5f /contrib/libucl/ucl.h
parent146886df6d250a376b92d1bb615cb93679a7d6e8 (diff)
downloadrspamd-bb5a9f8e451bc206e78c9d4d03eb4cbdbef260b3.tar.gz
rspamd-bb5a9f8e451bc206e78c9d4d03eb4cbdbef260b3.zip
[Minor] Massive spelling correction
by a bot https://github.com/ka7/misspell_fixer
Diffstat (limited to 'contrib/libucl/ucl.h')
-rw-r--r--contrib/libucl/ucl.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/contrib/libucl/ucl.h b/contrib/libucl/ucl.h
index ee03334e0..7c069e794 100644
--- a/contrib/libucl/ucl.h
+++ b/contrib/libucl/ucl.h
@@ -108,7 +108,7 @@ typedef enum ucl_error {
UCL_EMACRO, /**< Error processing a macro */
UCL_EINTERNAL, /**< Internal unclassified error */
UCL_ESSL, /**< SSL error */
- UCL_EMERGE /**< A merge error occured */
+ UCL_EMERGE /**< A merge error occurred */
} ucl_error_t;
/**
@@ -229,7 +229,7 @@ typedef struct ucl_object_s {
const char *key; /**< Key of an object */
struct ucl_object_s *next; /**< Array handle */
struct ucl_object_s *prev; /**< Array handle */
- uint32_t keylen; /**< Lenght of a key */
+ uint32_t keylen; /**< Length of a key */
uint32_t len; /**< Size of an object */
uint32_t ref; /**< Reference count */
uint16_t flags; /**< Object flags */
@@ -830,7 +830,7 @@ UCL_EXTERN ucl_object_iter_t ucl_object_iterate_reset (ucl_object_iter_t it,
const ucl_object_t *obj);
/**
- * Get the next object from the `obj`. This fucntion iterates over arrays, objects
+ * Get the next object from the `obj`. This function iterates over arrays, objects
* and implicit arrays
* @param iter safe iterator
* @param expand_values expand explicit arrays and objects
@@ -848,7 +848,7 @@ enum ucl_iterate_type {
};
/**
- * Get the next object from the `obj`. This fucntion iterates over arrays, objects
+ * Get the next object from the `obj`. This function iterates over arrays, objects
* and implicit arrays if needed
* @param iter safe iterator
* @param
@@ -1156,7 +1156,7 @@ UCL_EXTERN const ucl_object_t * ucl_comments_find (const ucl_object_t *comments,
* Move comment from `from` object to `to` object
* @param comments comments object
* @param what source object
- * @param whith destination object
+ * @param with destination object
* @return `true` if `from` has comment and it has been moved to `to`
*/
UCL_EXTERN bool ucl_comments_move (ucl_object_t *comments,
@@ -1391,7 +1391,7 @@ enum ucl_schema_error_code {
struct ucl_schema_error {
enum ucl_schema_error_code code; /**< error code */
char msg[128]; /**< error message */
- const ucl_object_t *obj; /**< object where error occured */
+ const ucl_object_t *obj; /**< object where error occurred */
};
/**
@@ -1399,7 +1399,7 @@ struct ucl_schema_error {
* @param schema schema object
* @param obj object to validate
* @param err error pointer, if this parameter is not NULL and error has been
* occured, then `err` is filled with the exact error definition.
* @return true if `obj` is valid using `schema`
*/
UCL_EXTERN bool ucl_object_validate (const ucl_object_t *schema,
@@ -1411,7 +1411,7 @@ UCL_EXTERN bool ucl_object_validate (const ucl_object_t *schema,
* @param obj object to validate
* @param root root schema object
* @param err error pointer, if this parameter is not NULL and error has been
* occured, then `err` is filled with the exact error definition.
* @return true if `obj` is valid using `schema`
*/
UCL_EXTERN bool ucl_object_validate_root (const ucl_object_t *schema,
@@ -1427,7 +1427,7 @@ UCL_EXTERN bool ucl_object_validate_root (const ucl_object_t *schema,
* @param root root schema object
* @param ext_refs external references (might be modified during validation)
* @param err error pointer, if this parameter is not NULL and error has been
* occured, then `err` is filled with the exact error definition.
* @return true if `obj` is valid using `schema`
*/
UCL_EXTERN bool ucl_object_validate_root_ext (const ucl_object_t *schema,
@@ -1399,7 +1399,7 @@ struct ucl_schema_error {
* @param obj object to validate
* @param err error pointer, if this parameter is not NULL and error has been
- * occured, then `err` is filled with the exact error definition.
+ * occurred, then `err` is filled with the exact error definition.
* @return true if `obj` is valid using `schema`
*/
@@ -1411,7 +1411,7 @@ UCL_EXTERN bool ucl_object_validate (const ucl_object_t *schema,
* @param root root schema object
* @param err error pointer, if this parameter is not NULL and error has been
- * occured, then `err` is filled with the exact error definition.
+ * occurred, then `err` is filled with the exact error definition.
* @return true if `obj` is valid using `schema`
*/
@@ -1427,7 +1427,7 @@ UCL_EXTERN bool ucl_object_validate_root (const ucl_object_t *schema,
* @param ext_refs external references (might be modified during validation)
* @param err error pointer, if this parameter is not NULL and error has been
- * occured, then `err` is filled with the exact error definition.
+ * occurred, then `err` is filled with the exact error definition.
* @return true if `obj` is valid using `schema`
*/